@@ -5,14 +5,13 @@ use warnings;
 package CPAN::Common::Index::LocalPackage;
 # ABSTRACT: Search index via custom local CPAN package flatfile
 
-our $VERSION = '0.007';
+our $VERSION = '0.010';
 
 use parent 'CPAN::Common::Index::Mirror';
 
 use Class::Tiny qw/source/;
 
 use Carp;
-use IO::Uncompress::Gunzip ();
 use File::Basename ();
 use File::Copy ();
 use File::Spec;
@@ -60,10 +59,13 @@ sub refresh_index {
     my $source = $self->source;
     my $basename = File::Basename::basename($source);
     if ( $source =~ /\.gz$/ ) {
+        Carp::croak "can't load gz source files without IO::Uncompress::Gunzip\n"
+          unless $CPAN::Common::Index::Mirror::HAS_IO_UNCOMPRESS_GUNZIP;
         ( my $uncompressed = $basename ) =~ s/\.gz$//;
         $uncompressed = File::Spec->catfile( $self->cache, $uncompressed );
         if ( !-f $uncompressed
               or File::stat::stat($source)->mtime > File::stat::stat($uncompressed)->mtime ) {
+            no warnings 'once';
             IO::Uncompress::Gunzip::gunzip( map { "$_" } $source, $uncompressed )
               or Carp::croak "gunzip failed: $IO::Uncompress::Gunzip::GunzipError\n";
         }
@@ -95,7 +97,7 @@ CPAN::Common::Index::LocalPackage - Search index via custom local CPAN package f
 
 =head1 VERSION
 
-version 0.007
+version 0.010
 
 =head1 SYNOPSIS
 
